@@ -100,12 +100,14 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::checkout::handlers::{create_handler, add_item_handler, remove_item_handler, confirm_items_handler, update_contact_handler, update_shipping_address_handler, update_fulfillment_type_handler, initiate_payment_handler};
 
             pub struct Config {
-                pub google_application_credentials: String
+                pub google_application_credentials: String,
+                pub payment_processing_topic: String
             }
 
             pub fn get_config() -> Config {
                 Config {
                     google_application_credentials: env::var("GOOGLE_APPLICATION_CREDENTIALS").unwrap(),
+                    payment_processing_topic: env::var("PAYMENT_PROCESSING_TOPIC").unwrap(),
                 }
             }
 
@@ -438,7 +440,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
                 let config = checkout_server::get_config();
 
-                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone()).await.map_err(|_| checkout_server::Error {
+                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone()).await.map_err(|_| checkout_server::Error {
                     code: "500".to_string(),
                     message: "failed to create internal context".to_string(),
                 })?;
